@@ -1684,6 +1684,8 @@ class DataSet(object):
 
     from nctoolkit.cleanup import disk_clean
 
+    from nctoolkit.clear import reset
+
     from nctoolkit.compare import compare
 
     from nctoolkit.compare_data import gt
@@ -1712,6 +1714,8 @@ class DataSet(object):
     from nctoolkit.esoteric import fix_nemo_ersem_grid
     from nctoolkit.esoteric import set_gridtype
     from nctoolkit.esoteric import no_leaps
+    from nctoolkit.esoteric import as_double
+    from nctoolkit.esoteric import as_type
 
     from nctoolkit.fill import fill_na
 
@@ -1773,12 +1777,12 @@ class DataSet(object):
 
     from nctoolkit.run import run
 
-    from nctoolkit.select import select
-    from nctoolkit.select import subset
+    from nctoolkit.subset import select
+    from nctoolkit.subset import subset
 
     from nctoolkit.setters import set_date
     from nctoolkit.setters import set_year
-    from nctoolkit.setters import set_missing
+    from nctoolkit.setters import as_missing
     from nctoolkit.setters import set_units
     from nctoolkit.setters import set_longnames
     from nctoolkit.setters import set_precision
@@ -1837,3 +1841,4 @@ class DataSet(object):
     from nctoolkit.zonals import zonal_range
 
     # Deprecated methods
+    from nctoolkit.deprecated import set_missing
