@@ -3,14 +3,17 @@ import subprocess
 from nctoolkit.runthis import run_this
 
 
-def cdo_command(self, command=None):
+def cdo_command(self, command=None, ensemble=False):
     """
     Apply a cdo command
 
     Parameters
     -------------
     command : string
-        cdo command to call. This command must be such that "cdo {command} infile outfile" will run.
+        cdo command to call. This command must be such that
+        "cdo {command} infile outfile" will run.
+    ensemble : bool
+        Is this an ensemble command?
     """
 
     # First, check that the command is valid
@@ -30,17 +33,17 @@ def cdo_command(self, command=None):
 
     cdo_methods = [mm for mm in cdo_methods if len(mm) > 0]
 
-    for x in command.split(" "):
+    for x in command.replace("-f ", "").replace("-z ", "").strip().split(" "):
         y = x.split(",")[0].replace("-", "")
-        if y not in cdo_methods:
-            raise ValueError("You have supplied an invalid cdo method:" + y)
+        if y not in cdo_methods and y != "nc4" and y != "zip_9":
+            raise ValueError(f"{y} is not a cdo method!" + y)
 
     # remove cdo from the command
 
     output = "ensemble"
     cdo_command = "cdo " + command + " "
 
-    if ("merge " in cdo_command) or ("mergetime " in cdo_command):
+    if ("merge " in cdo_command) or ("mergetime " in cdo_command) or ensemble:
         output = "one"
         self._merged = True
 
