@@ -318,6 +318,13 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
             error = errors[0]
             raise ValueError(f"CDO error: {error}. Please check variables supplied to nctoolkit")
 
+        text = re.compile(r"Variable name .* not found!")
+        errors = text.findall(error)
+        print(len(errors))
+        if len(errors) > 0:
+            error = errors[0]
+            raise ValueError(f"CDO error: {error}. Please check variables supplied to nctoolkit")
+
         text = re.compile(r"File has less then [0-9]* timesteps!")
         errors = text.findall(error)
         print(len(errors))
@@ -426,6 +433,12 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                 else:
                     remove_safe(target)
                     remove_safe(start_target)
+
+                    
+
+                    if  "Error (cdf_put_vara_double): NetCDF: Numeric conversion not representable" in str(result):
+                        raise ValueError("CDO error: Error (cdf_put_vara_double): NetCDF: Numeric conversion not representable. Tip: check if missing values are incorrectly set to large actual values!")
+
                     raise ValueError(
                         str(result1)
                         .replace("b'", "")
@@ -559,237 +572,241 @@ def run_this(os_command, self, output="one", out_file=None):
             self.history[-1] = os_command + " " + self.history[-1].replace("cdo ", " ")
             self.history[-1] = self.history[-1].replace("  ", " ")
 
-    if self._execute:
+    try:
+        if self._execute:
 
-        if ((output == "ensemble") and (len(self) > 1)) or (
-            (output == "ensemble") and (len(self) == 1)
-        ):
-            new_history = copy.deepcopy(self._hold_history)
+            if ((output == "ensemble") and (len(self) > 1)) or (
+                (output == "ensemble") and (len(self) == 1)
+            ):
+                new_history = copy.deepcopy(self._hold_history)
 
-            if len(self) == 1:
-                cores = 1
-            file_list = self.current
+                if len(self) == 1:
+                    cores = 1
+                file_list = self.current
 
-            if len(self.history) > len(self._hold_history):
-                os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
-                os_command = os_command.replace("  ", " ")
+                if len(self.history) > len(self._hold_history):
+                    os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
+                    os_command = os_command.replace("  ", " ")
 
-            if cores > 1:
-                pool = multiprocessing.Pool(cores)
-                target_list = []
-                results = dict()
-            else:
-                target_list = []
+                if cores > 1:
+                    pool = multiprocessing.Pool(cores)
+                    target_list = []
+                    results = dict()
+                else:
+                    target_list = []
 
-            for ff in file_list:
-                ff_command = os_command
+                for ff in file_list:
+                    ff_command = os_command
 
-                ff_command = f"{ff_command} {ff} "
-                if "infile09178" in ff_command:
-                    ff_command = " ".join(ff_command.split(" ")[:-2])
-                    ff_command = ff_command.replace("infile09178", ff)
+                    ff_command = f"{ff_command} {ff} "
+                    if "infile09178" in ff_command:
+                        ff_command = " ".join(ff_command.split(" ")[:-2])
+                        ff_command = ff_command.replace("infile09178", ff)
+
+                    target = temp_file("nc")
+
+                    if out_file is not None:
+                        target = out_file
+
+                    ff_command = f"{ff_command} {target}"
+                    ff_command = ff_command.replace("  ", " ")
+                    if " --sortname " in os_command:
+                        os_command = os_command.replace(" --sortname ", " ")
+                        os_command = os_command.replace("cdo  ", "cdo --sortname ")
+
+                    if "reduce_dim" in ff_command:
+                        ff_command = (
+                            ff_command.replace("reduce_dim", "")
+                            .replace(" - ", " ")
+                            .replace(" -- ", " ")
+                        )
+                        ff_command = ff_command.replace("cdo ", "cdo --reduce_dim ")
+
+                    ff_command = tidy_command(ff_command)
+
+                    zip_copy = False
+                    if self._zip and self._ncommands == 1:
+                        zip_copy = True
+
+                    format_it = False
+                    if self._format is not None:
+                        format_it = True
+                        if self._ncommands == 1:
+                            ff_command = ff_command.replace(
+                                "cdo ", f"cdo -f {self._format} copy "
+                            )
+                        else:
+                            ff_command = ff_command.replace(
+                                "cdo ", f"cdo -f {self._format} "
+                            )
+
+                    if self._zip and zip_copy and format_it is False:
+                        ff_command = ff_command.replace("cdo ", "cdo -z zip copy ")
+                    else:
+                        if self._zip:
+                            ff_command = ff_command.replace("cdo ", "cdo -z zip ")
+
+                    new_history.append(ff_command)
+
+                    if cores > 1:
+                        temp = pool.apply_async(
+                            run_cdo, [ff_command, target, out_file, False, self._precision]
+                        )
+                        results[ff] = temp
+                    else:
+
+                        target = run_cdo(
+                            ff_command, target, out_file, precision=self._precision
+                        )
+                        target_list.append(target)
+
+                if cores > 1:
+                    pool.close()
+                    pool.join()
+                    for k, v in results.items():
+                        target_list.append(v.get())
+
+                self.history = copy.deepcopy(new_history)
+                self.current = copy.deepcopy(target_list)
+
+                if cores == 1 or session_info["parallel"]:
+                    for ff in target_list:
+                        remove_safe(ff)
+
+                self.disk_clean()
+
+                cleanup()
+
+                self._hold_history = copy.deepcopy(self.history)
+
+                self._zip = False
+
+                self._ncommands = 0
+
+                self._format = None
+
+                return None
+
+            if ((output == "one") and (len(self) > 1)) or self._zip is False:
+
+                new_history = copy.deepcopy(self._hold_history)
+
+                if len(self.history) > len(self._hold_history):
+                    os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
+                    os_command = os_command.replace("  ", " ")
+
+                # ensure there is sufficient space in /tmp if it is to be used
+                if platform.system() == "Linux":
+                    all_sizes = 0
+
+                    for ff in self:
+                        if file_size(ff) is not None:
+                            all_sizes += file_size(ff)
+
+                    result = os.statvfs("/tmp/")
+                    result = result.f_frsize * result.f_bavail
+
+                    if result < (2 * all_sizes):
+                        session_info["temp_dir"] == "/var/tmp/"
 
                 target = temp_file("nc")
 
                 if out_file is not None:
                     target = out_file
 
-                ff_command = f"{ff_command} {target}"
-                ff_command = ff_command.replace("  ", " ")
-                if " --sortname " in os_command:
-                    os_command = os_command.replace(" --sortname ", " ")
-                    os_command = os_command.replace("cdo  ", "cdo --sortname ")
-
-                if "reduce_dim" in ff_command:
-                    ff_command = (
-                        ff_command.replace("reduce_dim", "")
-                        .replace(" - ", " ")
-                        .replace(" -- ", " ")
-                    )
-                    ff_command = ff_command.replace("cdo ", "cdo --reduce_dim ")
-
-                ff_command = tidy_command(ff_command)
+                os_command = (
+                    os_command + " [ " + str_flatten(self.current, " ") + " ] " + target
+                )
 
                 zip_copy = False
                 if self._zip and self._ncommands == 1:
                     zip_copy = True
 
                 format_it = False
+
                 if self._format is not None:
                     format_it = True
                     if self._ncommands == 1:
-                        ff_command = ff_command.replace(
+                        os_command = os_command.replace(
                             "cdo ", f"cdo -f {self._format} copy "
                         )
                     else:
-                        ff_command = ff_command.replace(
-                            "cdo ", f"cdo -f {self._format} "
-                        )
+                        os_command = os_command.replace("cdo ", f"cdo -f {self._format} ")
 
                 if self._zip and zip_copy and format_it is False:
-                    ff_command = ff_command.replace("cdo ", "cdo -z zip copy ")
+                    os_command = os_command.replace("cdo ", "cdo -z zip copy ")
                 else:
                     if self._zip:
-                        ff_command = ff_command.replace("cdo ", "cdo -z zip ")
+                        os_command = os_command.replace("cdo ", "cdo -z zip ")
 
-                new_history.append(ff_command)
+                if "infile09178" in os_command:
+                    os_command = os_command.replace(ff, "")
+                    os_command = os_command.replace("infile09178", ff)
 
-                if cores > 1:
-                    temp = pool.apply_async(
-                        run_cdo, [ff_command, target, out_file, False, self._precision]
-                    )
-                    results[ff] = temp
+                os_command = tidy_command(os_command)
+
+                if "mergetime" in os_command:
+                    try:
+                        target = run_cdo(
+                            os_command, target, out_file, precision=self._precision
+                        )
+                    except:
+
+                        var_list = []
+                        var_com = []
+
+                        for ff in self:
+                            var_list += nc_variables(ff)
+                            var_com.append(nc_variables(ff))
+                        new_list = []
+
+                        for var in set(var_list):
+                            if len(var_com) == len([x for x in var_com if var in x]):
+                                new_list.append(var)
+                        if version_below(session_info["cdo"], "1.9.9"):
+
+                            target = run_cdo(
+                                os_command, target, out_file, precision=self._precision
+                            )
+                        else:
+                            f_list = ",".join(new_list)
+                            os_command = os_command.replace(
+                                "-mergetime ", f'-mergetime -apply,"-selname,{f_list}" '
+                            )
+
+                            removed = ",".join(
+                                [x for x in set(var_list) if x not in new_list]
+                            )
+                            if len([x for x in set(var_list) if x not in new_list]) > 0:
+                                warnings.warn(
+                                    f"The following variables are not in all files, so were ignored when merging: {removed}"
+                                )
+
+                            target = run_cdo(
+                                os_command, target, out_file, precision=self._precision
+                            )
                 else:
-
-                    target = run_cdo(
-                        ff_command, target, out_file, precision=self._precision
-                    )
-                    target_list.append(target)
-
-            if cores > 1:
-                pool.close()
-                pool.join()
-                for k, v in results.items():
-                    target_list.append(v.get())
-
-            self.history = copy.deepcopy(new_history)
-            self.current = copy.deepcopy(target_list)
-
-            if cores == 1 or session_info["parallel"]:
-                for ff in target_list:
-                    remove_safe(ff)
-
-            self.disk_clean()
-
-            cleanup()
-
-            self._hold_history = copy.deepcopy(self.history)
-
-            self._zip = False
-
-            self._ncommands = 0
-
-            self._format = None
-
-            return None
-
-        if ((output == "one") and (len(self) > 1)) or self._zip is False:
-
-            new_history = copy.deepcopy(self._hold_history)
-
-            if len(self.history) > len(self._hold_history):
-                os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
-                os_command = os_command.replace("  ", " ")
-
-            # ensure there is sufficient space in /tmp if it is to be used
-            if platform.system() == "Linux":
-                all_sizes = 0
-
-                for ff in self:
-                    if file_size(ff) is not None:
-                        all_sizes += file_size(ff)
-
-                result = os.statvfs("/tmp/")
-                result = result.f_frsize * result.f_bavail
-
-                if result < (2 * all_sizes):
-                    session_info["temp_dir"] == "/var/tmp/"
-
-            target = temp_file("nc")
-
-            if out_file is not None:
-                target = out_file
-
-            os_command = (
-                os_command + " [ " + str_flatten(self.current, " ") + " ] " + target
-            )
-
-            zip_copy = False
-            if self._zip and self._ncommands == 1:
-                zip_copy = True
-
-            format_it = False
-
-            if self._format is not None:
-                format_it = True
-                if self._ncommands == 1:
-                    os_command = os_command.replace(
-                        "cdo ", f"cdo -f {self._format} copy "
-                    )
-                else:
-                    os_command = os_command.replace("cdo ", f"cdo -f {self._format} ")
-
-            if self._zip and zip_copy and format_it is False:
-                os_command = os_command.replace("cdo ", "cdo -z zip copy ")
-            else:
-                if self._zip:
-                    os_command = os_command.replace("cdo ", "cdo -z zip ")
-
-            if "infile09178" in os_command:
-                os_command = os_command.replace(ff, "")
-                os_command = os_command.replace("infile09178", ff)
-
-            os_command = tidy_command(os_command)
-
-            if "mergetime" in os_command:
-                try:
                     target = run_cdo(
                         os_command, target, out_file, precision=self._precision
                     )
-                except:
 
-                    var_list = []
-                    var_com = []
+                remove_safe(target)
 
-                    for ff in self:
-                        var_list += nc_variables(ff)
-                        var_com.append(nc_variables(ff))
-                    new_list = []
+                self.current = target
 
-                    for var in set(var_list):
-                        if len(var_com) == len([x for x in var_com if var in x]):
-                            new_list.append(var)
-                    if version_below(session_info["cdo"], "1.9.9"):
+                self.history = new_history
+                self.history.append(os_command)
 
-                        target = run_cdo(
-                            os_command, target, out_file, precision=self._precision
-                        )
-                    else:
-                        f_list = ",".join(new_list)
-                        os_command = os_command.replace(
-                            "-mergetime ", f'-mergetime -apply,"-selname,{f_list}" '
-                        )
+                self.disk_clean()
 
-                        removed = ",".join(
-                            [x for x in set(var_list) if x not in new_list]
-                        )
-                        if len([x for x in set(var_list) if x not in new_list]) > 0:
-                            warnings.warn(
-                                f"The following variables are not in all files, so were ignored when merging: {removed}"
-                            )
+                cleanup()
 
-                        target = run_cdo(
-                            os_command, target, out_file, precision=self._precision
-                        )
-            else:
-                target = run_cdo(
-                    os_command, target, out_file, precision=self._precision
-                )
+                self._hold_history = copy.deepcopy(self.history)
 
-            remove_safe(target)
+                self._zip = False
+                self._n_commands = 0
 
-            self.current = target
-
-            self.history = new_history
-            self.history.append(os_command)
-
-            self.disk_clean()
-
-            cleanup()
-
-            self._hold_history = copy.deepcopy(self.history)
-
-            self._zip = False
-            self._n_commands = 0
-
-            self._format = None
+                self._format = None
+    except Exception as e:
+        self.reset()
+        raise ValueError(e)
